

.. _plotexamples:

************************
Plotting examples in 1d
************************

.. seealso:: :ref:`setplot`, :ref:`plotexamples2d`

Normally most of the commands shown in these examples would go
in a function setplot(plotdata) that would set various attributes of the
object plotdata of class :ref:`ClawPlotData`.  

Then :class:`~pyclaw.plotters.Iplotclaw.Iplotclaw`
would be used to step through the frames, or the function
:meth:`~pyclaw.plotters.frametools.printframes`
would be used to print all the figures and create html pages
to facilitate stepping through them.

See :ref:`plotting` for more details on this process.

Contents:

.. toctree::
   :maxdepth: 2

   plotexample-acoustics-1d-1
   plotexample-acoustics-1d-2
   plotexample-acoustics-1d-3
   plotexample-acoustics-1d-4
   plotexample-acoustics-1d-5
   plotexample-acoustics-1d-6
